Read raw logs from one explicitly mapped folder per participant
Source:R/io_inputs.R
read_raw_logs_from_participant_dirs.RdRead raw logs from one explicitly mapped folder per participant
Usage
read_raw_logs_from_participant_dirs(
participant_dirs,
tz = "Europe/Berlin",
errors = c("raise", "warn", "ignore", "error"),
create_report = FALSE
)Examples
fixture <- system.file("extdata", "parity", "v1.0.0", package = "carwatch")
folders <- c(VP01 = file.path(fixture, "raw", "VP01"))
imported <- read_raw_logs_from_participant_dirs(folders, create_report = TRUE)
head(imported$source_audit)
#> # A tibble: 1 × 8
#> participant participant_folder source archive_member logical_source_file
#> <chr> <fs::path> <chr> <chr> <chr>
#> 1 VP01 …/parity/v1.0.0/raw/VP01 /tmp/… NA carwatch_parity_VP…
#> # ℹ 3 more variables: raw_event_count <int>, status <chr>, reason <chr>