R/io_inputs.R
summarize_source_audit.Rd
Compactly summarize a source audit
summarize_source_audit(source_audit)
Source audit returned by read_raw_logs_from_participant_dirs().
read_raw_logs_from_participant_dirs()
A one-column tibble with three values named raw_log_import: the number of selected logs, the total raw events in selected logs, and the number of distinct participants, in that order.
raw_log_import